@@ -226,7 +226,11 @@ class MacroServer(SardanaDevice):
         elements = self.macro_server.get_elements_info()
         value = dict(new=elements)
         value = CodecFactory().getCodec('utf8_json').encode(('', value))
-        self.ElementsCache = value
+        if SardanaServer.server_state == State.Running:
+            # Only cache value when the server is running
+            # If a client is reading Elements during server startup,
+            # the list might be incomplete and we don't want to cache that
+            self.ElementsCache = value
         return value
 
     #@DebugIt()
