@@ -269,7 +269,11 @@ class Pool(PyTango.LatestDeviceImpl, Logger):
             return value
         value = dict(new=self.pool.get_elements_info())
         value = CodecFactory().encode('utf8_json', ('', value))
-        self.ElementsCache = value
+        if SardanaServer.server_state == State.Running:
+            # Only cache value when the server is running
+            # If a client is reading Elements during server startup,
+            # the list might be incomplete and we don't want to cache that
+            self.ElementsCache = value
         return value
 
     #@DebugIt()
