@@ -1045,7 +1045,7 @@ class BaseMacroServer(MacroServerDevice):
             # in the event. Use name to obtain the element for removal.
             # See more details in #300.
             if "MacroCode" in element_data.get("interfaces", []):
-                old_element = self.getMacros()[element_data["full_name"]]
+                old_element = self.getMacros()[element_data["full_name"].lower()]
                 old_element_data = old_element.getData()
                 element = self._removeElement(old_element_data)
             else:
